changeset 746:717cdb23cc52 draft

Updated several tests.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 05 Aug 2015 12:32:27 +0200
parents 5e107fd36f67
children bfdcbd1179ce
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 72 insertions(+), 67 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Aug 04 12:57:38 2015 +0200
+++ b/ChangeLog	Wed Aug 05 12:32:27 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-05  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
 2015-08-04  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Aug 04 12:57:38 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Aug 05 12:32:27 2015 +0200
@@ -9331,7 +9331,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9340,13 +9340,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9355,13 +9355,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9370,13 +9370,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9385,13 +9385,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9400,13 +9400,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9415,13 +9415,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9430,13 +9430,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9445,13 +9445,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9460,13 +9460,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9475,9 +9475,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.yellow);
+    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.yellow);
     }
 
     /**
@@ -9331,7 +9331,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.magenta.
      *